Aloha Block Plugin Testcase

# Aloha, Blocks!

This example demoes the following use cases:

Editable/Non-Editable | Inline/Block-Level | inside editable/outside editable | Status
--- | --- | --- | ---
non-editable | block-level | outside editable | Tested
non-editable | block-level | inside editable | Tested
non-editable | inline | outside editable | Tested
non-editable | inline | inside editable | Tested
editable | block-level | outside editable | Tested
editable | block-level | inside editable | Tested
editable | inline | outside editable | -- not relevant --
editable | inline | inside editable | -- not relevant --

- A block which has sortable contents - Tested
- Nested blocks with editable in between - Tested
- Block Collections: Nested blocks WITHOUT editable in between - Tested
- Block Collections: Nested blocks WITHOUT editable in between (inside outer editable) - Tested

## (1)Non-editable (2)"Block"-Element Blocks (3)outside editable

### DefaultRenderer

This is a default aloha block without special type, which uses the DefaultRenderer. It is not editable and embedded as a "block" element.

### News Listing example

#### News Title 1

Drosera brevifolia (the dwarf, small or red sundew), is a carnivorous plant of the family Droseraceae and is the smallest sundew species native to the United States. This species differs considerably from the pink sundew, Drosera capillaris, by its wedge-shaped leaves, and distinctly deeper red to reddish purple color, noticeable when side by side with D. capillaris.

#### News Title 2

Bednarz studied Slavic studies, theatre and Eastern Europe history at universities in Hamburg, Wien and Moskow. His dissertation at university was over russian author Anton Chekhov. Since 1967 Bednarz worked for German television as Correspondent in Poland (1971–1977) and in Soviet Union (1977-1982). Later he was television presenter of german tv-programme Monitor on German broadcaster Westdeutscher Rundfunk. During these years Bednarz wrote several books over Eastern Europe countries and over the south of South America.

## (1)Non-editable (2)"Block"-Element Blocks (3)inside editable

Blocks can be embedded right inside an editable. "Block" element blocks are not very differen from inline element blocks. A simple example is the DefaultRenderer block type, which renders and stores the initial markup. Try copy and pasting or dragging it around!

### DefaultRenderer

This is a default aloha block without special type, which uses the DefaultRenderer. It is not editable and embedded as a "block" element.

### News Listing example

#### News Title 1

Drosera brevifolia (the dwarf, small or red sundew), is a carnivorous plant of the family Droseraceae and is the smallest sundew species native to the United States. This species differs considerably from the pink sundew, Drosera capillaris, by its wedge-shaped leaves, and distinctly deeper red to reddish purple color, noticeable when side by side with D. capillaris.

#### News Title 2

Bednarz studied Slavic studies, theatre and Eastern Europe history at universities in Hamburg, Wien and Moskow. His dissertation at university was over russian author Anton Chekhov. Since 1967 Bednarz worked for German television as Correspondent in Poland (1971–1977) and in Soviet Union (1977-1982). Later he was television presenter of german tv-programme Monitor on German broadcaster Westdeutscher Rundfunk. During these years Bednarz wrote several books over Eastern Europe countries and over the south of South America.

### Sortable News Listing example

#### News Title 1

Drosera brevifolia (the dwarf, small or red sundew), is a carnivorous plant of the family Droseraceae and is the smallest sundew species native to the United States. This species differs considerably from the pink sundew, Drosera capillaris, by its wedge-shaped leaves, and distinctly deeper red to reddish purple color, noticeable when side by side with D. capillaris.

#### News Title 2

Bednarz studied Slavic studies, theatre and Eastern Europe history at universities in Hamburg, Wien and Moskow. His dissertation at university was over russian author Anton Chekhov. Since 1967 Bednarz worked for German television as Correspondent in Poland (1971–1977) and in Soviet Union (1977-1982). Later he was television presenter of german tv-programme Monitor on German broadcaster Westdeutscher Rundfunk. During these years Bednarz wrote several books over Eastern Europe countries and over the south of South America.

### Table

Test1 | Test2
--- | ---
Foo | Bar

## (1)Non-editable (2)Inline Blocks (3)outside editable

### Inline Element

This is the Product Teaser Example: Try our new Big can of fresh Aloha soup (27 €), it tastes delicious!

Some other content here...

Stock Quote example: When you hover over the name of the Microsoft company, the stock quotes are shown.

Some more content...

### Floating Element

Super Dodge Ball Advance,Some Text released in Japan as Bakunetsu Dodgeball Fighters (爆熱ドッジボールファイターズ?, "Bakunetsu" meaning "Burning Heat"), dodge ball game based on the Super Dodge Ball. While based on the original Super Dodge Ball series, the game does not feature the Kunio-kun characters from the original game due to copyrights issues, as developer Million did not obtain the rights to the Kunio-kun characters until the following year.[citation needed] However, the game uses a remixed version of opening and ending songs from Technos Japan Corp's Super Dodge Ball games. from WikipediaSuper Dodge Ball Advance, released in Japan as Bakunetsu Dodgeball Fighters (爆熱ドッジボールファイターズ?, "Bakunetsu" meaning "Burning Heat"), dodge ball game based on the Super Dodge Ball. While based on the original Super Dodge Ball series, the game does not feature the Kunio-kun characters from the original game due to copyrights issues, as developer Million did not obtain the rights to the Kunio-kun characters until the following year.[citation needed] However, the game uses a remixed version of opening and ending songs from Technos Japan Corp's Super Dodge Ball games. from Wikipedia

Super Dodge Ball Advance, released in Japan as Bakunetsu Dodgeball Fighters (爆熱ドッジボールファイターズ?, "Bakunetsu" meaning "Burning Heat"), dodge ball game based on the Super Dodge Ball. While based on the original Super Dodge Ball series, the game does not feature the Kunio-kun characters from the original game due to copyrights issues, as developer Million did not obtain the rights to the Kunio-kun characters until the following year.[citation needed] However, the game uses a remixed version of opening and ending songs from Technos Japan Corp's Super Dodge Ball games. from Wikipedia

## (1)Non-editable (2)Inline Blocks (3)inside editable

### Inline Element

This is the Product Teaser Example: Try our new Big can of fresh Aloha soup (27 €), it tastes delicious!

Some other content here...

Stock Quote example: When you hover over the name of the Microsoft company, the stock quotes are shown.

Some more content...

### Floating Element

Super Dodge Ball Advance,Some Text released in Japan as Bakunetsu Dodgeball Fighters (爆熱ドッジボールファイターズ?, "Bakunetsu" meaning "Burning Heat"), dodge ball game based on the Super Dodge Ball. While based on the original Super Dodge Ball series, the game does not feature the Kunio-kun characters from the original game due to copyrights issues, as developer Million did not obtain the rights to the Kunio-kun characters until the following year.[citation needed] However, the game uses a remixed version of opening and ending songs from Technos Japan Corp's Super Dodge Ball games. from WikipediaSuper Dodge Ball Advance, released in Japan as Bakunetsu Dodgeball Fighters (爆熱ドッジボールファイターズ?, "Bakunetsu" meaning "Burning Heat"), dodge ball game based on the Super Dodge Ball. While based on the original Super Dodge Ball series, the game does not feature the Kunio-kun characters from the original game due to copyrights issues, as developer Million did not obtain the rights to the Kunio-kun characters until the following year.[citation needed] However, the game uses a remixed version of opening and ending songs from Technos Japan Corp's Super Dodge Ball games. from Wikipedia

Super Dodge Ball Advance, released in Japan as Bakunetsu Dodgeball Fighters (爆熱ドッジボールファイターズ?, "Bakunetsu" meaning "Burning Heat"), dodge ball game based on the Super Dodge Ball. While based on the original Super Dodge Ball series, the game does not feature the Kunio-kun characters from the original game due to copyrights issues, as developer Million did not obtain the rights to the Kunio-kun characters until the following year.[citation needed] However, the game uses a remixed version of opening and ending songs from Technos Japan Corp's Super Dodge Ball games. from Wikipedia

## (1)editable (2)"Block"-Element Blocks (3)outside editable

This Image Caption is editable through Aloha.

Williams, and other pilots who worked for British Airways claimed that their holiday pay was too low, because it only reflected his fixed salary, and not his bonuses. Williams' comprised a fixed annual salary, a "flying pay supplement" that went up the more he flew, and a "time away from base" which went up the more he was away from home. The flying and time away allowances were capped. Properly construed, his contract suggested that his holiday pay would be at the rate of only his fixed salary. Williams, however, contended that this was contrary to the Civil Aviation Working Time Directive,[1] as implemented by the Civil Aviation (Working Time) Regulations 2004,[2] (sector-specific implementations with the same objective as the Working Time Directive and the Working Time Regulations 1998 in this respect). In absence of particular provisions, the pay while on leave should be "normal remuneration". British Airways contended that because the Employment Rights Act 1996 sections 221 to 224 did not have provisions on how to determine a week's pay, the rate should be determined with reference to the contract. The Employment Appeal Tribunal allowed Williams' claim, but this was reversed in the Court of Appeal.[3] The Supreme Court made a reference to the European Court of Justice.

## (1)editable (2)"Block"-Element Blocks (3)inside editable

Williams, and other pilots who worked for British Airways claimed that their holiday pay was too low, because it only reflected his fixed salary, and not his bonuses. Williams' comprised a fixed annual salary, a "flying pay supplement" that went up the more he flew, and a "time away from base" which went up the more he was away from home. The flying and time away allowances were capped. Properly construed, his contract suggested that his holiday pay would be at the rate of only his fixed salary. Williams, however, contended that this was contrary to the Civil Aviation Working Time Directive,[1] as implemented by the Civil Aviation (Working Time) Regulations 2004,[2] (sector-specific implementations with the same objective as the Working Time Directive and the Working Time Regulations 1998 in this respect). In absence of particular provisions, the pay while on leave should be "normal remuneration". British Airways contended that because the Employment Rights Act 1996 sections 221 to 224 did not have provisions on how to determine a week's pay, the rate should be determined with reference to the contract. The Employment Appeal Tribunal allowed Williams' claim, but this was reversed in the Court of Appeal.[3] The Supreme Court made a reference to the European Court of Justice.

This Image Caption is editable through Aloha.

Williams, and other pilots who worked for British Airways claimed that their holiday pay was too low, because it only reflected his fixed salary, and not his bonuses. Williams' comprised a fixed annual salary, a "flying pay supplement" that went up the more he flew, and a "time away from base" which went up the more he was away from home. The flying and time away allowances were capped. Properly construed, his contract suggested that his holiday pay would be at the rate of only his fixed salary. Williams, however, contended that this was contrary to the Civil Aviation Working Time Directive,[1] as implemented by the Civil Aviation (Working Time) Regulations 2004,[2] (sector-specific implementations with the same objective as the Working Time Directive and the Working Time Regulations 1998 in this respect). In absence of particular provisions, the pay while on leave should be "normal remuneration". British Airways contended that because the Employment Rights Act 1996 sections 221 to 224 did not have provisions on how to determine a week's pay, the rate should be determined with reference to the contract. The Employment Appeal Tribunal allowed Williams' claim, but this was reversed in the Court of Appeal.[3] The Supreme Court made a reference to the European Court of Justice.

Williams, and other pilots who worked for British Airways claimed that their holiday pay was too low, because it only reflected his fixed salary, and not his bonuses. Williams' comprised a fixed annual salary, a "flying pay supplement" that went up the more he flew, and a "time away from base" which went up the more he was away from home. The flying and time away allowances were capped. Properly construed, his contract suggested that his holiday pay would be at the rate of only his fixed salary. Williams, however, contended that this was contrary to the Civil Aviation Working Time Directive,[1] as implemented by the Civil Aviation (Working Time) Regulations 2004,[2] (sector-specific implementations with the same objective as the Working Time Directive and the Working Time Regulations 1998 in this respect). In absence of particular provisions, the pay while on leave should be "normal remuneration". British Airways contended that because the Employment Rights Act 1996 sections 221 to 224 did not have provisions on how to determine a week's pay, the rate should be determined with reference to the contract. The Employment Appeal Tribunal allowed Williams' claim, but this was reversed in the Court of Appeal.[3] The Supreme Court made a reference to the European Court of Justice.

## Block which contains a variable number of editable columns

### The following CMS systems use Aloha:

## TYPO3 Phoenix

TYPO3 Phoenix is the next-generation Open Source CMS system built on FLOW3. FLOW3 is a PHP-based Enterprise Web Framework suitable for large applications.

This is some test with a nested block: Microsoft -- curious if it works!

## Gentics Content.Node

Gentics Content.Node is a leading CMS for big organizations and governments. The team behind Content.Node puts a lot of work into Aloha.

Here follows a non-editable block

This is a default aloha block without special type, which uses the DefaultRenderer. It is not editable and embedded as a "block" element.

Some more text with the Apple stocks

## Block which contains nested blocks (without editables in between)

## TYPO3 Phoenix

TYPO3 Phoenix is the next-generation Open Source CMS system built on FLOW3. FLOW3 is a PHP-based Enterprise Web Framework suitable for large applications.

This is some test with a nested block: Microsoft -- curious if it works!

## Gentics Content.Node

Gentics Content.Node is a leading CMS for big organizations and governments. The team behind Content.Node puts a lot of work into Aloha.

Here follows a non-editable block

This is a default aloha block without special type, which uses the DefaultRenderer. It is not editable and embedded as a "block" element.

Some more text with the Apple stocks

## Block which contains nested blocks (without editables in between); all inside an outer editable

#### Some editable content before

## TYPO3 Phoenix

TYPO3 Phoenix is the next-generation Open Source CMS system built on FLOW3. FLOW3 is a PHP-based Enterprise Web Framework suitable for large applications.

This is some test with a nested block: Microsoft -- curious if it works!

## Gentics Content.Node

Gentics Content.Node is a leading CMS for big organizations and governments. The team behind Content.Node puts a lot of work into Aloha.

Here follows a non-editable block

This is a default aloha block without special type, which uses the DefaultRenderer. It is not editable and embedded as a "block" element.

Some more text with the Apple stocks

Some editable content after

## Inline-Editable elements (not officially supported)

Here follows the editable product teaser example: Try our new Big can of fresh Aloha soup (27 €) - which enables some great stuff.